from __future__ import annotations

from ontopia_py.l0.Characteristic import Characteristic

from ..ns import *


class AccidentCircumstance(Characteristic):
    __type__ = ONTOIM["AccidentCircumstance"]
