from rdflib import Namespace
from ontopia_py.ns import *

# OntoIM Namespaces

ONTOIM = Namespace("https://w3id.org/ontoim/")

# OntoIM Controlled Vocabularies

ACCIDENT_CIRCUMSTANCES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/accident-circumstances/")
ACCIDENT_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/accident-types/")
ASSOCIATION_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/association-categories/")
CIVIL_STATUS_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/civil-status-categories/")
COMPANY_DEMOGRAPHIC_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/company-demographic-categories/")
HERITAGE_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/heritage-types/")
INVOLVED_PERSON_STATUSES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/involved-person-statuses/")
LAND_REGISTRY_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/land-registry-categories/")
ORGANIZATION_SECTIONS = Namespace("https://w3od.org/ontoim/controlled-vocabulary/organization-sections/")
PAVEMENT_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/pavement-types/")
REVELATION_UNITS = Namespace("https://w3od.org/ontoim/controlled-vocabulary/revelation-units/")
ROAD_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/road-categories/")
ROAD_CONTEXTS = Namespace("https://w3od.org/ontoim/controlled-vocabulary/road-contexts/")
ROAD_SIGNAL_PRESENCE_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/road-signal-presence-types/")
ROAD_SIGNAL_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/road-signal-types/")
ROAD_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/road-types/")
ROADBED_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/roadbed-types/")
SCHOOL_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/school-types/")
VEHICLE_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/vehicle-categories/")
WASTE_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/waste-categories/")
WEATHER_CONDITIONS = Namespace("https://w3od.org/ontoim/controlled-vocabulary/weather-conditions/")